@@ -32,7 +32,8 @@ def test_pde_consistency(pde_class, dim):
     field = eq.evolution_rate(state)
     assert field.grid == grid
     rhs = eq._make_pde_rhs_numba(state)
-    np.testing.assert_allclose(field.data, rhs(state.data, 0))
+    res = rhs(state.data, 0)
+    np.testing.assert_allclose(field.data, res)
 
     # compare to generic implementation
     assert isinstance(eq.expression, str)
